@@ -39,7 +39,7 @@ from airflow.contrib.operators import kubernetes_pod_operator
 
 default_args = {{
             'owner': 'airflow',
-            'depends_on_past': True,
+            'depends_on_past': {depends_on_past},
             'start_date': {start_date_as_str},
             'email_on_failure': False,
             'email_on_retry': False,
@@ -54,7 +54,8 @@ dag = DAG(
 )
 """.format(dag_id=dag_deployment_id,
            start_date_as_str=start_date_as_str,
-           schedule_interval=workflow.schedule_interval))
+           schedule_interval=workflow.schedule_interval,
+           depends_on_past=workflow.depends_on_past))
 
     def get_job(workflow_job):
         return workflow_job.job
@@ -75,16 +76,15 @@ dag = DAG(
     is_delete_operator_pod=True,
     retries={retries},
     retry_delay=datetime.timedelta(seconds={retry_delay}),
-    dag=dag,
-    execution_timeout=datetime.timedelta(milliseconds={execution_timeout}))
+    dag=dag)
 """.format(job_var=job_var,
           task_id=task_id,
           docker_image = docker_repository+":"+build_ver,
           bf_job= workflow.workflow_id+"."+job.id,
           root_folder=root_package_name,
           retries=job.retry_count if hasattr(job, 'retry_count') else 3,
-          retry_delay=job.retry_pause_sec if hasattr(job, 'retry_pause_sec') else 60,
-          execution_timeout=job.job_execution_timeout))
+          retry_delay=job.retry_pause_sec if hasattr(job, 'retry_pause_sec') else 60))
+
         for d in dependencies:
             up_job_var = "t" + str(get_job(d).id)
             dag_chunks.append("{job_var}.set_upstream({up_job_var})".format(job_var=job_var, up_job_var=up_job_var))
